@@ -362,3 +362,10 @@ class UrlEnum(Enum):
                                         'jyzh', 'khlx', 'zjlx', 'zjhm', 'xsjg', 'ztfhtx', 'ztshtx', 'bz', 'state')
                          )
     '''fof估值子基金 - 查询子基金列表'''
+        # fof历史净值 - 查询历史净值
+    FOF_LSJZ = UrlCfg('http://%s/admin/sm/fof/sy/lsjz', 'get', 'ams-admin',
+                         lambda x: {},
+                         lambda y: {'access_token': y['access_token'],'dm':y['jjdm']},
+                         supportFields=('jzrq', 'ljjz', 'jjjz')
+                         )
+    '''fof估值子基金 - 查询历史净值'''
\ No newline at end of file
