@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from hbshare.fe.asset_allocation.efficient_frontier_solver import EF
 from hbshare.fe.asset_allocation.black_litterman_solver import BL
 from hbshare.fe.asset_allocation.data_loader import Loader
 from hbshare.fe.common.util.exception import InputParameterError
@@ -27,6 +28,14 @@ def nearestPD(A):
     A3 = (A2 + A2.T) / 2.0
     if isPD(A3):
         return A3
+    spacing = np.spacing(la.norm(A))
+    I = np.eye(A.shape[0])
+    k = 1
+    while not isPD(A3):
+        mineig = np.min(np.real(la.eigvals(A3)))
+        A3 += I * (-mineig * k**2 + spacing)
+        k += 1
+    return A3
 
 def correct_cov(cov):
     if not isPD(cov):
@@ -75,7 +84,7 @@ def get_w_eq(asset_type, asset_list, date):
 class BlackLitterman:
     def __init__(self, asset_type, asset_list, method, start_date, end_date, is_reblance, reblance_type, n, frequency, compute_risk_days,
                        lb_list=None, ub_list=None, total_weight=None,
-                       w_eq=None, risk_aversion=0.01, tau=0.01, P=np.array([]), Q=np.array([]), omega=np.array([])):
+                       w_eq=None, risk_aversion=None, tau=None, P=None, Q=None, omega=None, risk_free_rate=None):
         self.asset_type = asset_type
         self.asset_list = asset_list
         self.method = method
@@ -86,16 +95,17 @@ class BlackLitterman:
         self.n = n
         self.frequency = frequency
         self.compute_risk_days = compute_risk_days
-        self.lb_list = lb_list if lb_list is not None else [0.0] * len(self.asset_list)
-        self.ub_list = ub_list if ub_list is not None else [1.0] * len(self.asset_list)
-        self.total_weight = total_weight if total_weight is not None else 1.0
-        self.w_eq = w_eq if w_eq is not None else [1.0 / len(self.asset_list)] * len(self.asset_list)
+        self.lb_list = [0.0] * len(self.asset_list) if lb_list is None or lb_list == [] else lb_list
+        self.ub_list = [1.0] * len(self.asset_list) if ub_list is None or ub_list == [] else ub_list
+        self.total_weight = 1.0 if total_weight is None else total_weight
+        self.w_eq = [1.0 / len(self.asset_list)] * len(self.asset_list) if w_eq is None or w_eq == [] else w_eq
         self.w_eq = [w / sum(self.w_eq) for w in self.w_eq]
-        self.risk_aversion = risk_aversion
-        self.tau = tau
-        self.P = np.matrix(P)
-        self.Q = np.matrix(Q).T
-        self.omega = np.matrix(omega)
+        self.risk_aversion = 3.0 if risk_aversion is None else risk_aversion
+        self.tau = 0.05 if tau is None else tau
+        self.P = np.matrix(np.array([])) if P is None or P == [] else np.matrix(np.array(P))
+        self.Q = np.matrix(np.array([])).T if Q is None or Q == [] else np.matrix(np.array(Q)).T
+        self.omega = np.matrix(np.array([])) if omega is None or omega == [] else np.matrix(np.array(omega))
+        self.risk_free_rate = 0.03 if risk_free_rate is None else risk_free_rate
         self._verify_input_param()
         self._load()
         self._init_data()
@@ -120,6 +130,7 @@ class BlackLitterman:
         verify_type(self.P, 'P', np.matrix)
         verify_type(self.Q, 'Q', np.matrix)
         verify_type(self.omega, 'omega', np.matrix)
+        verify_type(self.risk_free_rate, 'risk_free_rate', float)
         if self.asset_type not in ['index', 'fund']:
             msg = "asset_type not supported, check your input"
             logger.error(msg)
@@ -148,7 +159,7 @@ class BlackLitterman:
             logger.error(msg)
             raise InputParameterError(message=msg)
         if len(self.lb_list) != len(self.asset_list) or len(self.ub_list) != len(self.asset_list):
-            msg = "lb_list or ub_list are not the same length with asset_list, check your input"
+            msg = "lb_list or ub_list must be the same length with asset_list, check your input"
             logger.error(msg)
             raise InputParameterError(message=msg)
         if len([i for i in self.lb_list if (i >= 0.0 and i <= 1.0)]) != len(self.asset_list):
@@ -163,6 +174,10 @@ class BlackLitterman:
             msg = "total_weight must be between 0 and 1, check your input"
             logger.error(msg)
             raise InputParameterError(message=msg)
+        if len(self.w_eq) != len(self.asset_list):
+            msg = "w_eq must be the same length with asset_list, check your input"
+            logger.error(msg)
+            raise InputParameterError(message=msg)
         if len([i for i in self.w_eq if (i >= 0.0 and i <= 1.0)]) != len(self.asset_list):
             msg = "w_eq must be between 0 and 1, check your input"
             logger.error(msg)
@@ -183,10 +198,14 @@ class BlackLitterman:
             msg = "the confidence matrix error, check your input"
             logger.error(msg)
             raise InputParameterError(message=msg)
+        if self.risk_free_rate <= 0:
+            msg = "risk_free_rate must be larger than 0, check your input"
+            logger.error(msg)
+            raise InputParameterError(message=msg)
 
     def _load(self):
         self.calendar_df = Loader().read_cal('19900101', self.end_date)
-        self.calendar_df = self.calendar_df.rename(columns={'JYRQ': 'CALENDAR_DATE', 'SFJJ': 'IS_OPEN', 'SFZM': 'IS_WEEK_END', 'SFYM': 'IS_MONTH_END'})
+        self.calendar_df = self.calendar_df.rename(columns={'jyrq': 'CALENDAR_DATE', 'sfjj': 'IS_OPEN', 'sfzm': 'IS_WEEK_END', 'sfym': 'IS_MONTH_END'})
         self.calendar_df['CALENDAR_DATE'] = self.calendar_df['CALENDAR_DATE'].astype(str)
         self.calendar_df = self.calendar_df.sort_values('CALENDAR_DATE')
         self.calendar_df['IS_OPEN'] = self.calendar_df['IS_OPEN'].astype(int).replace({0: 1, 1: 0})
@@ -232,18 +251,14 @@ class BlackLitterman:
             self.market_index_nav_df = self.market_index_nav_df.sort_index()
 
             self.nav_df = pd.concat([self.mutual_index_nav_df, self.private_index_nav_df, self.market_index_nav_df], axis=1)
-            for asset in [asset for asset in self.asset_list if asset not in self.nav_df.columns]:
-                self.nav_df[asset] = np.nan
-            self.nav_df = self.nav_df[self.asset_list].sort_index()
 
         if self.asset_type == 'fund':
             self.mutual_fund_nav_df = Loader().read_mutual_fund_cumret_given_codes(self.asset_list, self.start_date_backup, self.end_date)
-            self.mutual_fund_nav_df = self.mutual_fund_nav_df[['FUND_CODE', 'TRADE_DATE', 'CUM_RET']] if len(self.mutual_fund_nav_df) != 0 else pd.DataFrame(columns=['FUND_CODE', 'TRADE_DATE', 'CUM_RET'])
+            self.mutual_fund_nav_df = self.mutual_fund_nav_df[['FUND_CODE', 'TRADE_DATE', 'ADJ_NAV']] if len(self.mutual_fund_nav_df) != 0 else pd.DataFrame(columns=['FUND_CODE', 'TRADE_DATE', 'ADJ_NAV'])
             self.mutual_fund_nav_df = self.mutual_fund_nav_df.drop_duplicates()
             self.mutual_fund_nav_df['TRADE_DATE'] = self.mutual_fund_nav_df['TRADE_DATE'].astype(str)
-            self.mutual_fund_nav_df = self.mutual_fund_nav_df.pivot(index='TRADE_DATE', columns='FUND_CODE', values='CUM_RET')
+            self.mutual_fund_nav_df = self.mutual_fund_nav_df.pivot(index='TRADE_DATE', columns='FUND_CODE', values='ADJ_NAV')
             self.mutual_fund_nav_df = self.mutual_fund_nav_df.sort_index()
-            self.mutual_fund_nav_df = 0.01 * self.mutual_fund_nav_df + 1
 
             self.private_fund_nav_df = Loader().read_private_fund_adj_nav_given_codes(self.asset_list, self.start_date_backup, self.end_date)
             self.private_fund_nav_df = self.private_fund_nav_df[['FUND_CODE', 'TRADE_DATE', 'ADJ_NAV']] if len(self.private_fund_nav_df) != 0 else pd.DataFrame(columns=['FUND_CODE', 'TRADE_DATE', 'ADJ_NAV'])
@@ -253,48 +268,58 @@ class BlackLitterman:
             self.private_fund_nav_df = self.private_fund_nav_df.sort_index()
 
             self.nav_df = pd.concat([self.mutual_fund_nav_df, self.private_fund_nav_df], axis=1)
-            for asset in [asset for asset in self.asset_list if asset not in self.nav_df.columns]:
-                self.nav_df[asset] = np.nan
+
+        nan_nav_list = [asset for asset in self.asset_list if asset not in self.nav_df.columns]
+        if len(nan_nav_list) == 0:
             self.nav_df = self.nav_df[self.asset_list].sort_index()
+        else:
+            msg = "{0} no nav data".format(','.join(nan_nav_list))
+            logger.error(msg)
+            raise InputParameterError(message=msg)
         return
 
     def _init_data(self):
         # 确定再平衡时点
-        self.start_trade_date = self.calendar_df[self.calendar_df['CALENDAR_DATE'] == self.start_date]['TRADE_DATE'].values[0]
-        if not self.is_reblance:
-            reblance_list = [self.start_trade_date]
+        if len(self.trade_cal[(self.trade_cal['TRADE_DATE'] >= self.start_date) & (self.trade_cal['TRADE_DATE'] <= self.end_date)]) == 0:
+            msg = "no reblance dates between start_date and end_date, check your input"
+            logger.error(msg)
+            raise InputParameterError(message=msg)
         else:
-            if self.frequency == 'day':
-                reblance_list = self.calendar_df[self.calendar_df['IS_OPEN'] == 1]['TRADE_DATE'].unique().tolist()
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
-                reblance_list = reblance_list[::self.n]
-            elif self.frequency == 'week':
-                reblance_list = self.calendar_df[self.calendar_df['IS_OPEN'] == 1]['TRADE_DATE'].unique().tolist()
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
-                reblance_list = reblance_list[::self.n * 5]
-            elif self.frequency == 'month':
-                reblance_list = self.calendar_df['YEAR_MONTH'].unique().tolist()
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date[:6]) and (date <= self.end_date[:6])]
-                reblance_list = reblance_list[::self.n]
-                reblance_list = [date + self.start_trade_date[6:] for date in reblance_list]
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
-                reblance_list = [self.calendar_df[(self.calendar_df['IS_OPEN'] == 1) & (self.calendar_df['CALENDAR_DATE'] <= date)]['TRADE_DATE'].iloc[-1] for date in reblance_list]
-            elif self.frequency == 'quarter':
-                reblance_list = self.calendar_df['YEAR_MONTH'].unique().tolist()
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date[:6]) and (date <= self.end_date[:6])]
-                reblance_list = reblance_list[::self.n * 3]
-                reblance_list = [date + self.start_trade_date[6:] for date in reblance_list]
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
-                reblance_list = [self.calendar_df[(self.calendar_df['IS_OPEN'] == 1) & (self.calendar_df['CALENDAR_DATE'] <= date)]['TRADE_DATE'].iloc[-1] for date in reblance_list]
-            elif self.frequency == 'year':
-                reblance_list = self.calendar_df['YEAR_MONTH'].unique().tolist()
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date[:6]) and (date <= self.end_date[:6])]
-                reblance_list = reblance_list[::self.n * 12]
-                reblance_list = [date + self.start_trade_date[6:] for date in reblance_list]
-                reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
-                reblance_list = [self.calendar_df[(self.calendar_df['IS_OPEN'] == 1) & (self.calendar_df['CALENDAR_DATE'] <= date)]['TRADE_DATE'].iloc[-1] for date in reblance_list]
-            else:
+            self.start_trade_date = self.trade_cal[self.trade_cal['TRADE_DATE'] >= self.start_date]['TRADE_DATE'].values[0]
+            if not self.is_reblance:
                 reblance_list = [self.start_trade_date]
+            else:
+                if self.frequency == 'day':
+                    reblance_list = self.calendar_df[self.calendar_df['IS_OPEN'] == 1]['TRADE_DATE'].unique().tolist()
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
+                    reblance_list = reblance_list[::self.n]
+                elif self.frequency == 'week':
+                    reblance_list = self.calendar_df[self.calendar_df['IS_OPEN'] == 1]['TRADE_DATE'].unique().tolist()
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
+                    reblance_list = reblance_list[::self.n * 5]
+                elif self.frequency == 'month':
+                    reblance_list = self.calendar_df['YEAR_MONTH'].unique().tolist()
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date[:6]) and (date <= self.end_date[:6])]
+                    reblance_list = reblance_list[::self.n]
+                    reblance_list = [date + self.start_trade_date[6:] for date in reblance_list]
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
+                    reblance_list = [self.calendar_df[(self.calendar_df['IS_OPEN'] == 1) & (self.calendar_df['CALENDAR_DATE'] <= date)]['TRADE_DATE'].iloc[-1] for date in reblance_list]
+                elif self.frequency == 'quarter':
+                    reblance_list = self.calendar_df['YEAR_MONTH'].unique().tolist()
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date[:6]) and (date <= self.end_date[:6])]
+                    reblance_list = reblance_list[::self.n * 3]
+                    reblance_list = [date + self.start_trade_date[6:] for date in reblance_list]
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
+                    reblance_list = [self.calendar_df[(self.calendar_df['IS_OPEN'] == 1) & (self.calendar_df['CALENDAR_DATE'] <= date)]['TRADE_DATE'].iloc[-1] for date in reblance_list]
+                elif self.frequency == 'year':
+                    reblance_list = self.calendar_df['YEAR_MONTH'].unique().tolist()
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date[:6]) and (date <= self.end_date[:6])]
+                    reblance_list = reblance_list[::self.n * 12]
+                    reblance_list = [date + self.start_trade_date[6:] for date in reblance_list]
+                    reblance_list = [date for date in reblance_list if (date >= self.start_trade_date) and (date <= self.end_date)]
+                    reblance_list = [self.calendar_df[(self.calendar_df['IS_OPEN'] == 1) & (self.calendar_df['CALENDAR_DATE'] <= date)]['TRADE_DATE'].iloc[-1] for date in reblance_list]
+                else:
+                    reblance_list = [self.start_trade_date]
 
         # 确定每个再平衡时点所需数据
         trading_day_list = self.calendar_df[self.calendar_df['IS_OPEN'] == 1]['TRADE_DATE'].unique().tolist()
@@ -308,61 +333,118 @@ class BlackLitterman:
             date_list = self.calendar_df[self.calendar_df['IS_OPEN'] == 1]['TRADE_DATE'].unique().tolist()
             self.q = 250
         preprocessed_data = dict()
-        if not (self.nav_df.empty or self.nav_df.reindex(date_list).interpolate().dropna().empty or self.nav_df.dropna(axis=1, how='all').shape[1] != len(self.asset_list)):
-            nav_df = self.nav_df.reindex(date_list).interpolate().dropna().sort_index()
-            nav_df = nav_df / nav_df.iloc[0]
-            ret_df = nav_df.pct_change().dropna()
+        self.reason_df = pd.DataFrame(index=reblance_list, columns=['原因'])
+        if not (self.nav_df.empty or self.nav_df.reindex(date_list).interpolate().dropna(how='all').empty or self.nav_df.dropna(axis=1, how='all').shape[1] != len(self.asset_list)):
+            nav_df = self.nav_df.reindex(date_list).interpolate().dropna().sort_index(how='all')
+            ret_df = nav_df.pct_change().dropna(how='all')
             for date in reblance_list:
                 interval_data = dict()
                 start = [td for td in trading_day_list if td <= date][-self.compute_risk_days]
                 end = date
-                cov_df_prior = ret_df[(ret_df.index >= start) & (ret_df.index <= end)].cov() * self.q
-                cov_df_prior = correct_cov(cov_df_prior)
-                cov_df_prior = np.matrix(cov_df_prior)
-                interval_data['cov_df'] = linalg.inv(self.tau * cov_df_prior) + self.P.T * linalg.inv(self.omega) * self.P
-                interval_data['cov_df'] = correct_cov(interval_data['cov_df'])
-                interval_data['cov_df'] = linalg.inv(interval_data['cov_df'])
-                w_eq = np.matrix(self.w_eq).T #if self.w_eq is not None else get_w_eq(self.asset_type, self.asset_list, date)
-                ret_df_prior = self.risk_aversion * cov_df_prior * w_eq
-                interval_data['ret_df'] = interval_data['cov_df'] * (linalg.inv(self.tau * cov_df_prior) * ret_df_prior + self.P.T * linalg.inv(self.omega) * self.Q)
-                interval_data['ret_df'] = pd.DataFrame(interval_data['ret_df'])
-                interval_data['cov_df'] = pd.DataFrame(interval_data['cov_df'])
-                preprocessed_data[date] = interval_data
+                need_length = len(ret_df[(ret_df.index >= start) & (ret_df.index < end)])
+                density = [len(self.nav_df[(self.nav_df.index >= start) & (self.nav_df.index < end)][[asset]].dropna()) / float(need_length) if need_length != 0 else 0.0 for asset in self.asset_list]
+                if min(density) < 0.3:
+                    density_ser = pd.Series(density)
+                    density_ser = density_ser[density_ser < 0.3]
+                    self.reason_df.loc[date] = '{0}：{1}当期净值数据不足，无法计算预期风险！'.format(date, ','.join([self.asset_list[i] for i in density_ser.index.tolist()]))
+                    interval_data['ret_df'] = pd.DataFrame()
+                    interval_data['cov_df'] = pd.DataFrame()
+                    preprocessed_data[date] = interval_data
+                else:
+                    cov_df_prior = ret_df[(ret_df.index >= start) & (ret_df.index < end)].cov() * self.q
+                    cov_df_prior = correct_cov(cov_df_prior)
+                    cov_df_prior = np.matrix(cov_df_prior)
+                    interval_data['cov_df'] = linalg.inv(self.tau * cov_df_prior) + self.P.T * linalg.inv(self.omega) * self.P
+                    interval_data['cov_df'] = correct_cov(interval_data['cov_df'])
+                    interval_data['cov_df'] = linalg.inv(interval_data['cov_df'])
+                    w_eq = np.matrix(self.w_eq).T #if self.w_eq is not None else get_w_eq(self.asset_type, self.asset_list, date)
+                    ret_df_prior = self.risk_aversion * cov_df_prior * w_eq
+                    interval_data['ret_df'] = interval_data['cov_df'] * (linalg.inv(self.tau * cov_df_prior) * ret_df_prior + self.P.T * linalg.inv(self.omega) * self.Q)
+                    interval_data['ret_df'] = pd.DataFrame(interval_data['ret_df'])
+                    interval_data['cov_df'] = pd.DataFrame(interval_data['cov_df'])
+                    preprocessed_data[date] = interval_data
         else:
             for date in reblance_list:
+                self.reason_df.loc[date] = '{0}：{1}当期净值数据不足，无法计算预期风险！'.format(date, ','.join(self.asset_list))
                 interval_data = dict()
                 interval_data['ret_df'] = pd.DataFrame()
                 interval_data['cov_df'] = pd.DataFrame()
                 preprocessed_data[date] = interval_data
         self.preprocessed_data = preprocessed_data
+        # ret_df_list, cov_df_list = [], []
+        # for date in sorted(list(self.preprocessed_data.keys())):
+        #     ret_df_list.append(self.preprocessed_data[date]['ret_df'])
+        #     cov_df_list.append(self.preprocessed_data[date]['cov_df'])
+        # all_ret_df = pd.concat(ret_df_list)
+        # all_cov_df = pd.concat(cov_df_list)
+        # if len(all_ret_df) == 0 and len(all_cov_df) != 0:
+        #     print('no enough nav data for computing return model!')
+        # if len(all_ret_df) != 0 and len(all_cov_df) == 0:
+        #     print('no enough nav data for computing risk model!')
+        # if len(all_ret_df) == 0 and len(all_cov_df) == 0:
+        #     print('no enough nav data for computing return model and risk model!')
         return
 
     def get_all(self):
-        weight_list, status_list = [], []
+        weight_list, status_list, ef_weight_list = [], [], []
         for date, period_data in self.preprocessed_data.items():
             if period_data['ret_df'].empty or period_data['cov_df'].empty:
                 logger.warning("{0}: ret_df or cov_df is empty !".format(date))
-                weight = pd.DataFrame(index=[date], columns=self.asset_list)
-                status = pd.DataFrame(index=[date], columns=['OPTIMAL'])
+                weight = pd.DataFrame(index=[date], columns=self.asset_list + ['cash'])
+                status = pd.DataFrame(index=[date], columns=['优化状态'], data=['infeasible'])
+                status = status.merge(self.reason_df, left_index=True, right_index=True, how='left')
+                ef_weight = pd.DataFrame(index=range(22), columns=['date', 'group'] + self.asset_list + ['cash', 'sigma', 'r'])
+                ef_weight['date'] = date
+                ef_weight['group'] = list(range(21)) + ['result']
             else:
-                self.ret = period_data['ret_df']
-                self.cov = period_data['cov_df']
-                weight, status = BL(self.asset_list, self.ret, self.cov, self.risk_aversion, self.lb_list, self.ub_list, self.total_weight).solve()
-                weight = pd.DataFrame(weight, columns=[date]).T
-                status = pd.DataFrame(index=[date], columns=['优化状态'], data=[status])
+                try:
+                    self.ret = period_data['ret_df']
+                    self.cov = period_data['cov_df']
+                    weight, status = BL(self.asset_list, self.ret, self.cov, self.risk_aversion, self.lb_list, self.ub_list, self.total_weight).solve()
+                    weight = pd.DataFrame(weight, columns=[date]).T
+                    reason = '{0}：模型当期无优化解！' if status == 'infeasible' else np.nan
+                    status = pd.DataFrame(index=[date], columns=['优化状态', '原因'], data=[[status, reason]])
+                except:
+                    weight = pd.DataFrame(index=[date], columns=self.asset_list + ['cash'])
+                    status = pd.DataFrame(index=[date], columns=['优化状态'], data=['infeasible'])
+                    status = status.merge(self.reason_df, left_index=True, right_index=True, how='left')
+                try:
+                    self.ret_ori = period_data['ret_df']
+                    self.cov_ori = period_data['cov_df']
+                    ef_weight = EF(self.asset_list, self.ret_ori, self.cov_ori, self.risk_free_rate, self.lb_list, self.ub_list, self.total_weight, weight).solve()
+                    ef_weight = ef_weight.reset_index().rename(columns={'index': 'group'})
+                    ef_weight['date'] = date
+                    ef_weight = ef_weight[['date', 'group'] + self.asset_list + ['cash', 'sigma', 'r']]
+                except:
+                    ef_weight = pd.DataFrame(index=range(22), columns=['date', 'group'] + self.asset_list + ['cash', 'sigma', 'r'])
+                    ef_weight['date'] = date
+                    ef_weight['group'] = list(range(21)) + ['result']
             weight_list.append(weight)
             status_list.append(status)
+            ef_weight_list.append(ef_weight)
             print('[{0}]/[{1}] done'.format(date, self.method))
         weight_df = pd.concat(weight_list)
         status_df = pd.concat(status_list)
         # 权重归一化（本版本不支持有现金配置）
         weight_df = weight_df[self.asset_list]
         weight_df['TOTAL'] = weight_df.sum(axis=1)
+        weight_df['TOTAL'] = weight_df['TOTAL'].replace(0.0, np.nan)
         weight_df = weight_df.apply(lambda x: x.iloc[:len(self.asset_list)] / x[-1], axis=1)
         if self.reblance_type == 'init_weight':
-            weight_df.iloc[1:] = weight_df.iloc[0]
-            status_df.iloc[1:] = status_df.iloc[0]
-        return weight_df, status_df
+            start_index = weight_df.dropna().index[0]
+            weight_df.loc[weight_df.index > start_index, :] = np.nan
+            weight_df = weight_df.fillna(method='ffill')
+            status_df.loc[status_df.index > start_index, :] = np.nan
+            status_df = status_df.fillna(method='ffill')
+        ef_weight_df = pd.concat(ef_weight_list)
+        # 权重归一化（本版本不支持有现金配置）
+        ef_weight_df['TOTAL'] = ef_weight_df[self.asset_list].sum(axis=1)
+        ef_weight_df['TOTAL'] = ef_weight_df['TOTAL'].replace(0.0, np.nan)
+        ef_weight_df[self.asset_list] = ef_weight_df[self.asset_list + ['TOTAL']].apply(lambda x: x.iloc[:len(self.asset_list)] / x[-1], axis=1)
+        ef_weight_df = ef_weight_df[['date', 'group'] + self.asset_list + ['sigma', 'r']]
+        # if len(weight_df.dropna()) == 0:
+        #     print('no optimal results!')
+        return weight_df, status_df, ef_weight_df
 
 
 if __name__ == '__main__':
@@ -372,21 +454,21 @@ if __name__ == '__main__':
     # mutual_fund: ['002943', '688888', '000729']
     # private_fund: ['SGK768', 'SX8958', 'SR4480']
 
-    weight_df, status_df = BlackLitterman(asset_type='fund',  # index（只支持市场指数）, fund（只支持公募基金）
-                                          asset_list=['002943', '688888', '000729'],
-                                          method='black_litterman',  # black_litterman
-                                          start_date='20181231',
-                                          end_date='20220704',
-                                          is_reblance=True,   # True, False
-                                          reblance_type='init_target',  # init_weight，init_target
-                                          n=3,
-                                          frequency='month',  # day, week, month, quarter, year
-                                          compute_risk_days=120,  # 交易日
-                                          w_eq=[0.3, 0.3, 0.4],
-                                          risk_aversion=2.0,
-                                          tau=0.01,
-                                          P=np.array([[1.0, 0.0, 0.0], [1.0, -1.0, 0.0]]),
-                                          Q=np.array([0.05, 0.02]),
-                                          omega=np.array([[0.05, 0.0], [0.0, 0.03]])
-                                          ).get_all()
-    print(weight_df, status_df)
\ No newline at end of file
+    weight_df, status_df, ef_weight_df = BlackLitterman(asset_type='index',  # index
+                                                        asset_list=['000300', '000906', 'CBA00301'],
+                                                        method='black_litterman',  # black_litterman
+                                                        start_date='20181231',
+                                                        end_date='20220704',
+                                                        is_reblance=True,   # True, False
+                                                        reblance_type='init_target',  # init_weight, init_target
+                                                        n=3,
+                                                        frequency='month',  # day, week, month, quarter, year
+                                                        compute_risk_days=120,  # 交易日
+                                                        w_eq=[0.3, 0.3, 0.4],
+                                                        risk_aversion=3.0,
+                                                        tau=0.05,
+                                                        P=[[1.0, 0.0, 0.0], [1.0, -1.0, 0.0]],
+                                                        Q=[0.05, 0.02],
+                                                        omega=[[0.5, 0.0], [0.0, 0.3]]
+                                                        ).get_all()
+    print(weight_df, status_df, ef_weight_df)
\ No newline at end of file
