@@ -32,7 +32,7 @@ class HBDB:
         return df
 
     def read_fund_info(self):
-        sql = "select jjdm, jjmc, jjjc, clrq, zzrq, cpfl, kffb, jjfl, ejfl from st_fund.t_st_gm_jjxx where cpfl='2'"
+        sql = "select jjdm, jjmc, jjjc, clrq, zzrq, cpfl, jjfl, ejfl, kffb from st_fund.t_st_gm_jjxx where cpfl='2' and m_opt_type<>'03'"
         df = self.get_df(sql, db='funduser')
         return df
 
@@ -52,15 +52,20 @@ class HBDB:
         return df
 
     def read_fund_manager_given_code(self, code):
-        sql = "select jjdm, rydm, ryxm, ryzw, bdrq, ryzt, rzrq, lrrq, lryy from st_fund.t_st_gm_jjjl where jjdm='{0}'".format(code)
+        sql = "select jjdm, rydm, ryxm, ryzw, ryzt, bdrq, rzrq, lrrq, lryy from st_fund.t_st_gm_jjjl where jjdm='{0}' and m_opt_type <> '03'".format(code)
         df = self.get_df(sql, db='funduser')
         return df
 
-    def read_fund_given_manager_code(self,manager_code):
-        sql = "select jjdm, rydm, ryxm, ryzw, bdrq, ryzt, rzrq, lrrq, lryy from st_fund.t_st_gm_jjjl where rydm='{0}'".format(manager_code)
+    def read_fund_given_manager_code(self, manager_code):
+        sql = "select jjdm, rydm, ryxm, ryzw, ryzt, bdrq, rzrq, lrrq, lryy from st_fund.t_st_gm_jjjl where rydm='{0}' and m_opt_type <> '03'".format(manager_code)
         df = self.get_df(sql, db='funduser')
         return df
 
+    def read_manager_info_given_manager_code(self, manager_code):
+        sql = "select rydm, ryxm, ryxb, ryxl, ryjj from st_main.t_st_gg_ryjl where rydm='{0}' and m_opt_type <> '03'".format(manager_code)
+        df = self.get_df(sql, db='alluser')
+        return df
+
     def read_fund_target_given_code(self, code):
         sql = "select jjdm, tzmb from funddb.JJXX2 where jjdm='{0}'".format(code)
         df = self.get_df(sql, db='readonly')
@@ -81,6 +86,12 @@ class HBDB:
         df = self.get_df(sql, db='funduser')
         return df
 
+    def read_fund_share_given_codes(self, codes):
+        codes = '"' + '","'.join(codes) + '"'
+        sql = "select jjdm, bblb, jsrq, plrq, qsrq, qcfe, qjsgfe, cfzjfe, wjshfe, qmfe from st_fund.t_st_gm_febd where jjdm in ({0}) and m_opt_type<>'03'".format(codes)
+        df = self.get_df(sql, db='funduser')
+        return df
+
     def read_fund_holder_given_code(self, code):
         sql = "select jjdm, jsrq, ggrq, jgcyfe, jgcybl, grcyfe, grcybl from st_fund.t_st_gm_fecyrbd where jjdm='{0}'".format(code)
         df = self.get_df(sql, db='funduser')
@@ -101,6 +112,11 @@ class HBDB:
         df = self.get_df(sql, db='funduser')
         return df
 
+    def read_fund_position_given_date(self, date):
+        sql = "select jjdm, jsrq, jjzzc, gptzsz, zqzsz, jjtzszhj, hbzjsz from st_fund.t_st_gm_zcpz where jsrq='{0}'".format(date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
     def read_fund_cr_given_code(self, code):
         sql = "select jjdm, jsrq, qsdzb, qsdzbtlpj, qwdzb, qwdzbtlpj from st_fund.t_st_gm_cgjzd where jjdm='{0}'".format(code)
         df = self.get_df(sql, db='funduser')
@@ -111,6 +127,12 @@ class HBDB:
         df = self.get_df(sql, db='funduser')
         return df
 
+    def read_fund_turnover_given_codes(self, codes):
+        codes = '"' + '","'.join(codes) + '"'
+        sql = "select jjdm, jsrq, tjqj, hsl from st_fund.t_st_gm_jjhsl where jjdm in ({0})".format(codes)
+        df = self.get_df(sql, db='funduser')
+        return df
+
     def read_fund_nav_given_code(self, code):
         sql = "select jjdm, jzrq, jjjz, ljjz from st_fund.t_st_gm_jjjz where jjdm='{0}'".format(code)
         df = self.get_df(sql, db='funduser')
@@ -136,6 +158,86 @@ class HBDB:
         df = self.get_df(sql, db='funduser')
         return df
 
+    def read_fund_return_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, rqnp, zbnp, zbnhnp from st_fund.t_st_gm_rqjhb where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_return_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, rqnp, zbnp, nhzbnp from st_hedge.t_st_sm_qjhb_zx where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='highuser')
+        return df
+
+    def read_fund_volatility_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, tjrq, zblb, zbnp, nhzbnp from st_fund.t_st_gm_zqjbdl where m_opt_type <> '03' and jjdm='{0}' and tjrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_volatility_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, zbnp, nhzbnp from st_hedge.t_st_sm_qjbdlzp_zx where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='highuser')
+        return df
+
+    def read_fund_maxdrawdown_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, zbnp, zdhchfts, zdhccxts from st_fund.t_st_gm_rqjzdhc where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_maxdrawdown_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, zbnp, hfts from st_hedge.t_st_sm_qjzdhc_zx where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='highuser')
+        return df
+
+    def read_fund_sharpe_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, tjrq, zblb, zbnp, nhzbnp from st_fund.t_st_gm_zqjxpbl where m_opt_type <> '03' and jjdm='{0}' and tjrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_sharpe_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, zbnp, nhzbnp from st_hedge.t_st_sm_qjxpblzp_zx where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='highuser')
+        return df
+
+    def read_fund_calmar_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, zbnp from st_fund.t_st_gm_rqjkmbl where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_calmar_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, zbnp from st_hedge.t_st_sm_qjkmbl_zx where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='highuser')
+        return df
+
+    def read_fund_winratio_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, tjyf, zblb, zbnp from st_fund.t_st_gm_yqjtzsl where m_opt_type <> '03' and jjdm='{0}' and tjyf >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_winratio_period_given_code_and_date(self, code, date):
+        sql = "select jjdm, jzrq, zblb, zbnp from st_hedge.t_st_sm_qjtzslyp_zx where m_opt_type <> '03' and jjdm='{0}' and jzrq >= '{1}'".format(code, date)
+        df = self.get_df(sql, db='highuser')
+        return df
+
+    def read_fund_return_year_given_code(self, code):
+        sql = "select jjdm, tjnf, rqzh, rq1n, hb1n from st_fund.t_st_gm_nhb where m_opt_type <> '03' and jjdm='{0}'".format(code)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_return_year_given_code(self, code):
+        sql = "select jjdm, tjnf, hblb, rqzh, rq1n, hb1n, nhhb1n from st_hedge.t_st_sm_nhb_ls where m_opt_type <> '03' and jjdm='{0}'".format(code)
+        df = self.get_df(sql, db='highuser')
+        return df
+
+    def read_fund_return_month_given_code(self, code):
+        sql = "select jjdm, tjyf, rqzh, rq1y, hb1y from st_fund.t_st_gm_yhb where m_opt_type <> '03' and jjdm='{0}'".format(code)
+        df = self.get_df(sql, db='funduser')
+        return df
+
+    def read_private_fund_return_month_given_code(self, code):
+        sql = "select jjdm, tjyf, rqzh, rq1y, hb1y from st_hedge.t_st_sm_yhb where m_opt_type <> '03' and jjdm='{0}'".format(code)
+        df = self.get_df(sql, db='highuser')
+        return df
+
     def read_fund_samekind_return_given_code_and_date(self, code, date):
         sql = "select jjdm, jzrq, zblb, pmnpyj, slnpyj, zbnpyj, pmnpej, slnpej, zbnpej, zbnhnpyj, zbnhnpej from st_fund.t_st_gm_rqjhbpm where jjdm='{0}' and jzrq >= '{1}'".format(code, date)
         df = self.get_df(sql, db='funduser')
@@ -217,22 +319,22 @@ class HBDB:
         return df
 
     def read_stock_valuation_given_date(self, date):
-        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.TradingDay, 'yyyyMMdd') AS TRADE_DATE, a.TotalMV AS MARKET_VALUE, a.PE AS PE_TTM, a.PB AS PB_LF, a.PEG, a.DividendRatio AS DIVIDEND_RATIO_TTM from hsjy_gg.LC_DIndicesForValuation a left join hsjy_gg.SecuMain b on a.InnerCode=b.InnerCode where to_char(a.TradingDay, 'yyyyMMdd')='{0}'".format(date)
+        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.TradingDay, 'yyyyMMdd') AS TRADE_DATE, a.TotalMV AS MARKET_VALUE, a.PE AS PE_TTM, a.PB AS PB_LF, a.PEG, a.DividendRatio AS DIVIDEND_RATIO_TTM, a.ForwardPEHR AS FORWARD_PEHR from hsjy_gg.LC_DIndicesForValuation a left join hsjy_gg.SecuMain b on a.InnerCode=b.InnerCode where to_char(a.TradingDay, 'yyyyMMdd')='{0}'".format(date)
         df = self.get_df(sql, db='readonly')
         return df
 
     def read_star_stock_valuation_given_date(self, date):
-        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.TradingDay, 'yyyyMMdd') AS TRADE_DATE, a.TotalMV AS MARKET_VALUE, a.PETTM AS PE_TTM, a.PB AS PB_LF, a.PEG, a.DividendRatioTTM AS DIVIDEND_RATIO_TTM from hsjy_gg.LC_STIBDIndiForValue a left join hsjy_gg.SecuMain b on a.InnerCode=b.InnerCode where to_char(a.TradingDay, 'yyyyMMdd')='{0}'".format(date)
+        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.TradingDay, 'yyyyMMdd') AS TRADE_DATE, a.TotalMV AS MARKET_VALUE, a.PETTM AS PE_TTM, a.PB AS PB_LF, a.PEG, a.DividendRatioTTM AS DIVIDEND_RATIO_TTM, a.ForwardPEHR AS FORWARD_PEHR from hsjy_gg.LC_STIBDIndiForValue a left join hsjy_gg.SecuMain b on a.InnerCode=b.InnerCode where to_char(a.TradingDay, 'yyyyMMdd')='{0}'".format(date)
         df = self.get_df(sql, db='readonly')
         return df
 
     def read_stock_finance_given_date(self, date):
-        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.InfoPublDate, 'yyyyMMdd') AS PUBLISH_DATE, to_char(a.EndDate, 'yyyyMMdd') AS END_DATE, a.NetProfit AS NET_PROFIT, a.MainIncomePS AS MAIN_INCOME_PS, a.ROETTM AS ROE_TTM, a.GrossIncomeRatioTTM AS GROSS_INCOME_RATIO_TTM, a.NetProfitRatioTTM AS NET_PROFIT_RATIO_TTM, a.EPSTTM AS EPS_TTM, a.OperCashFlowPSTTM AS OPER_CASH_FLOW_PS_TTM, a.NetAssetPS AS NET_ASSET_PS from hsjy_gg.LC_MainIndexNew a left join hsjy_gg.SecuMain b on a.CompanyCode=b.CompanyCode where to_char(a.EndDate, 'yyyyMMdd')='{0}'".format(date)
+        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.InfoPublDate, 'yyyyMMdd') AS PUBLISH_DATE, to_char(a.EndDate, 'yyyyMMdd') AS END_DATE, a.NetProfit AS NET_PROFIT, a.MainIncomePS AS MAIN_INCOME_PS, a.ROETTM AS ROE_TTM, a.GrossIncomeRatioTTM AS GROSS_INCOME_RATIO_TTM, a.NetProfitRatioTTM AS NET_PROFIT_RATIO_TTM, a.EPSTTM AS EPS_TTM, a.OperCashFlowPSTTM AS OPER_CASH_FLOW_PS_TTM, a.NetAssetPS AS NET_ASSET_PS from hsjy_gg.LC_MainIndexNew a left join hsjy_gg.SecuMain b on a.CompanyCode=b.CompanyCode where to_char(a.EndDate, 'yyyyMMdd')='{0}' and substr(b.SECUCODE, 0, 1) in ('0', '3', '6') and length(b.SECUCODE) = 6".format(date)
         df = self.get_df(sql, db='readonly')
         return df
 
     def read_star_stock_finance_given_date(self, date):
-        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.InfoPublDate, 'yyyyMMdd') AS PUBLISH_DATE, to_char(a.EndDate, 'yyyyMMdd') AS END_DATE, a.NPParentCompanyOwners AS NET_PROFIT, a.MainIncomePS AS MAIN_INCOME_PS, a.ROETTM AS ROE_TTM, a.GrossIncomeRatioTTM AS GROSS_INCOME_RATIO_TTM, a.NetProfitRatioTTM AS NET_PROFIT_RATIO_TTM, a.EPSTTM AS EPS_TTM, a.OperCashFlowPSTTM AS OPER_CASH_FLOW_PS_TTM, a.NetAssetPS AS NET_ASSET_PS from hsjy_gg.LC_STIBMainIndex a left join hsjy_gg.SecuMain b on a.CompanyCode=b.CompanyCode where to_char(a.EndDate, 'yyyyMMdd')='{0}' and a.IfMerged=1 and a.IfAdjusted=2".format(date)
+        sql = "select b.SECUCODE AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.InfoPublDate, 'yyyyMMdd') AS PUBLISH_DATE, to_char(a.EndDate, 'yyyyMMdd') AS END_DATE, a.NPParentCompanyOwners AS NET_PROFIT, a.MainIncomePS AS MAIN_INCOME_PS, a.ROETTM AS ROE_TTM, a.GrossIncomeRatioTTM AS GROSS_INCOME_RATIO_TTM, a.NetProfitRatioTTM AS NET_PROFIT_RATIO_TTM, a.EPSTTM AS EPS_TTM, a.OperCashFlowPSTTM AS OPER_CASH_FLOW_PS_TTM, a.NetAssetPS AS NET_ASSET_PS from hsjy_gg.LC_STIBMainIndex a left join hsjy_gg.SecuMain b on a.CompanyCode=b.CompanyCode where to_char(a.EndDate, 'yyyyMMdd')='{0}' and substr(b.SECUCODE, 0, 1) in ('0', '3', '6') and length(b.SECUCODE) = 6 and a.IfMerged=1 and a.IfAdjusted=2".format(date)
         df = self.get_df(sql, db='readonly')
         return df
 
@@ -262,7 +364,7 @@ class HBDB:
     #     return df
 
     def read_stock_industry(self):
-        sql = "select zqdm, flmc, fldm, fljb, hyhfbz, qsrq, jsrq, sfyx, credt_etl from st_fund.t_st_gm_zqhyflb"
+        sql = "select zqdm, flmc, fldm, fljb, hyhfbz, qsrq, jsrq, sfyx, credt_etl from st_fund.t_st_gm_zqhyflb where m_opt_type <> '03'"
         df = self.get_df(sql, db='funduser')
         return df
 
@@ -344,6 +446,18 @@ class HBDB:
         df = self.get_df(sql, db='funduser', page_size=200000)
         return df
 
+    def read_fund_nav_given_date(self, date, codes):
+        codes = '"' + '","'.join(codes) + '"'
+        sql = "select jjdm, jzrq, jjjz, ljjz from st_fund.t_st_gm_jjjz where jzrq='{0}' and jjdm in ({1}) ".format(date, codes)
+        df = self.get_df(sql, db='funduser', page_size=200000)
+        return df
+
+    def read_fund_nav_adj_given_date(self, date, codes):
+        codes = '"' + '","'.join(codes) + '"'
+        sql = "select jjdm, jzrq, fqdwjz, hbfh, hbcl, hbdr from st_fund.t_st_gm_rhb where jzrq='{0}' and jjdm in ({1}) ".format(date, codes)
+        df = self.get_df(sql, db='funduser', page_size=200000)
+        return df
+
     def read_finance_data_given_date(self, date):
         sql = "select b.SecuCode AS TICKER_SYMBOL, b.ChiNameAbbr AS SEC_SHORT_NAME, to_char(a.InfoPublDate, 'yyyyMMdd') AS PUBLISH_DATE, to_char(a.EndDate, 'yyyyMMdd') AS END_DATE, ROETTM AS ROE_TTM, ROATTM AS ROA_TTM, ROICTTM AS ROIC_TTM, NetProfitRatioTTM AS NET_PROFIT_RATIO_TTM, GrossIncomeRatioTTM AS GROSS_INCOME_RATIO_TTM, EBITToToAssetsTTM AS EBIT_ASSET_RATIO_TTM, a.NetProfit AS NET_PROFIT, a.MainIncomePS AS INCOME_PS from hsjy_gg.LC_MainIndexNew a left join hsjy_gg.SecuMain b on a.CompanyCode=b.CompanyCode where to_char(a.EndDate, 'yyyyMMdd')='{0}'".format(date)
         df = self.get_df(sql, db='readonly', page_size=200000)
@@ -365,8 +479,8 @@ class HBDB:
         return df
 
     def read_fund_cumret_given_code(self, code, start, end):
-        sql = "SELECT a.jjdm AS FUND_CODE, b.jzrq AS TRADE_DATE, b.hbcl AS CUM_RET FROM funddb.jjxx1 a, funddb.jjhb b WHERE a.cpfl = '2' AND a.jjdm = b.jjdm AND a.jjzt not in ('3', 'c') AND a.m_opt_type <> '03' AND a.jjdm = '{0}' AND b.jzrq >= {1} AND b.jzrq <= {2} order by b.jzrq".format(code, start, end)
-        df = self.get_df(sql, db='readonly', page_size=200000)
+        sql = "SELECT a.jjdm AS FUND_CODE, b.jzrq AS TRADE_DATE, b.hbcl AS CUM_RET FROM st_fund.t_st_gm_jjxx a, st_fund.t_st_gm_rhb b WHERE a.cpfl = '2' AND a.jjdm = b.jjdm AND a.jjzt not in ('3', 'c') AND a.m_opt_type <> '03' AND a.jjdm = '{0}' AND b.jzrq >= {1} AND b.jzrq <= {2} order by b.jzrq".format(code, start, end)
+        df = self.get_df(sql, db='funduser', page_size=200000)
         return df
 
     def read_private_fund_cumret_given_code(self, code, start, end):
@@ -379,6 +493,11 @@ class HBDB:
         df = self.get_df(sql, db='readonly')
         return df
 
+    def read_mutual_fund_nav_adj_given_date(self, date):
+        sql = "SELECT jjdm, jzrq, hbfh, hbcl, hbdr, fqdwjz FROM st_fund.t_st_gm_rhb WHERE jzrq='{0}' and m_opt_type <> '03'".format(date)
+        df = self.get_df(sql, db='funduser')
+        return df
+
     def read_stock_info(self):
         sql = "SELECT zqdm, zqjc, ssrq FROM st_ashare.t_st_ag_zqzb where zqlb=1 and sszt=1"
         df = self.get_df(sql, db='alluser', page_size=200000)
@@ -399,6 +518,15 @@ class HBDB:
         df = self.get_df(sql, db='readonly', page_size=200000)
         return df
 
+    def read_fund_stock_change_given_date(self, date):
+        sql = "select b.SecuCode AS FUND_CODE, date_format(a.EndDate, '%Y%m%d') AS END_DATE, date_format(a.InfoPublDate, '%Y%m%d') AS PUBLISH_DATE, a.ReportType AS REPORT_TYPE, a.ChangeType AS CHANGE_TYPE, a.SecuCode AS TICKER_SYMBOL, a.SecuName AS SEC_SHORT_NAME, a.TradeSum AS TRADE_SUM, a.RatioInNVAtBegin AS TS_IN_BNAV, a.RatioInNVAtEnd AS TS_IN_ENAV from hsjy_jj.MF_StockChangeAll a left join hsjy_jj.SecuMain b on a.InnerCode=b.InnerCode where date_format(a.EndDate, '%Y%m%d')='{0}'".format(date)
+        df = self.get_df(sql, db='alluser', page_size=200000)
+        return df
+
+    def read_industry_symbol(self):
+        sql = "select hyhfbz, fldm, flmc, zsdm, qsrq, jsrq, fljb, sfyx from st_market.t_st_zs_hyzsdmdyb where m_opt_type <> '03'"
+        df = self.get_df(sql, db='alluser', page_size=200000)
+        return df
 
 if __name__ == '__main__':
     dates = HBDB().read_fund_barra_attribution_given_code('450004')
