@@ -10,7 +10,7 @@
 """
 
 
-from hbshare.quant.CChen.load_data import *
-from hbshare.quant.CChen.fund_perf import *
+from hbshare.quant.CChen.data.data import *
+from hbshare.quant.CChen.fund_stats.perf import *
 # from hbshare.CChen.output import *
 from hbshare.quant.CChen.fut import *
