@@ -64,7 +64,8 @@ exchange_dict = {
 HSJY_PRODUCT_CODE = {
     'IH': 46,
     'IF': 3145,
-    'IC': 4978
+    'IC': 4978,
+    'IM': 39144,
 }
 
 # 虚拟合约代码
@@ -88,6 +89,12 @@ HSJY_VIRTUAL_CONTRACT = {
             '当季': 2006537,
             '次季': 2006538,
         },
+        'IM': {
+            '当月': 2043183,
+            '次月': 2043184,
+            '当季': 2043185,
+            '次季': 2043186,
+        },
     }
 }
 
