@@ -3,8 +3,9 @@ import pandas as pd
 import numpy as np
 from hbshare.quant.CChen.cta_factor.factor_func import factor_compute
 from hbshare.quant.CChen.cta_factor.factor_algo import (
-    carry, tsmom, tsrev, xsmom, xsrev, tswr, xswr, mr, mrchg, tsmr, tsbasismom, xsbasismom, tspoichg, xspoichg, xssigma,
-    xsmr, xstsmr, xsmrchg
+    tscarry, carry, tsmom, tsrev, xsmom, xsrev, tswr, xswr, mr, mrchg, tsmr,
+    tsbasismom, xsbasismom, tspoichg, xspoichg, xssigma,
+    xsmr, xstsmr, xsmrchg, tspvolchg, xspvolchg, tsskew, xsskew
 )
 
 
@@ -94,6 +95,16 @@ def run(sql_path, sql_info):
         sql_info=sql_info, to_sql_path=sql_path
     )
 
+    factor_compute(
+        window_days_list=window_days_list, data=data, factor_func=tscarry, liq_days=liq_d,
+        sql_info=sql_info, to_sql_path=sql_path
+    )
+
+    factor_compute(
+        window_days_list=window_days_list[1:], data=data, factor_func=tsskew, liq_days=liq_d,
+        sql_info=sql_info, to_sql_path=sql_path
+    )
+
     factor_compute(
         window_days_list=window_days_list, data=data, factor_func=tsrev, liq_days=liq_d,
         sql_info=sql_info, to_sql_path=sql_path
@@ -104,6 +115,11 @@ def run(sql_path, sql_info):
         sql_info=sql_info, to_sql_path=sql_path
     )
 
+    factor_compute(
+        window_days_list=window_days_list[1:], hedge_ratio_list=[50, 75], data=data, factor_func=xsskew, liq_days=liq_d,
+        sql_info=sql_info, to_sql_path=sql_path
+    )
+
     factor_compute(
         window_days_list=window_days_list, hedge_ratio_list=[50, 75], data=data, factor_func=xsrev, liq_days=liq_d,
         sql_info=sql_info, to_sql_path=sql_path
@@ -114,11 +130,21 @@ def run(sql_path, sql_info):
         sql_info=sql_info, to_sql_path=sql_path
     )
 
+    factor_compute(
+        window_days_list=window_days_list, data=data, factor_func=tspvolchg, liq_days=liq_d,
+        sql_info=sql_info, to_sql_path=sql_path
+    )
+
     factor_compute(
         window_days_list=window_days_list, hedge_ratio_list=[50, 75], data=data, factor_func=xspoichg, liq_days=liq_d,
         sql_info=sql_info, to_sql_path=sql_path
     )
 
+    factor_compute(
+        window_days_list=window_days_list, hedge_ratio_list=[50, 75], data=data, factor_func=xspvolchg, liq_days=liq_d,
+        sql_info=sql_info, to_sql_path=sql_path
+    )
+
     factor_compute(
         window_days_list=window_days_list,
         hedge_ratio_list=[50, 75],
