@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding:utf-8
-from hbshare.quant.CChen.load_data import load_funds_data, load_funds_alpha
-from hbshare.quant.CChen.fund_perf import ret
+from hbshare.quant.CChen.data.data import load_funds_data, load_funds_alpha
+from hbshare.quant.CChen.fund_stats.perf import ret
 import pandas as pd
 import numpy as np
 import pyecharts.options as opts
@@ -15,11 +15,12 @@ from hbshare.quant.CChen.cons import index_underlying, underlying_code
 from hbshare.quant.CChen.fut import (
     wind_fin_fut_index,
     wind_com_fut_sec_index,
+    wind_stk_index_basis,
     fin_fut_daily_k_by_contracts,
     fut_com_amount_by_ex,
     rolling_volatility,
 )
-from hbshare.quant.CChen.load_hsjy import load_fut_fin
+from hbshare.quant.CChen.data.hsjy_data import load_fut_fin
 from hbshare.quant.CChen.stk import load_index
 from hbshare.quant.CChen.cons import sql_write_path_hb, HSJY_VIRTUAL_CONTRACT
 
@@ -27,8 +28,16 @@ pymysql.install_as_MySQLdb()
 
 
 def nav_lines(
-        fund_list, start_date, end_date, title='', zz=False, axis_cross=None,
-        db_path=sql_write_path_hb['daily'], cal_path=sql_write_path_hb['work'], all_selected=True, print_info=True
+        fund_list,
+        start_date,
+        end_date,
+        title='',
+        zz=False,
+        axis_cross=None,
+        db_path=sql_write_path_hb['daily'],
+        cal_path=sql_write_path_hb['work'],
+        all_selected=True,
+        print_info=True
 ):
     if axis_cross:
         axis_cross = opts.TooltipOpts(trigger="axis", axis_pointer_type="cross")
@@ -116,8 +125,18 @@ def nav_lines(
 
 
 def gen_grid(
-        end_date, funds, zz=False, lookback_years=3, grid_width=1200, grid_height=500, pos_top=23, axis_cross=None,
-        db_path=sql_write_path_hb['work'], cal_path=sql_write_path_hb['daily'], all_selected=True, print_info=True
+        end_date,
+        funds,
+        zz=False,
+        lookback_years=3,
+        grid_width=1200,
+        grid_height=500,
+        pos_top=23,
+        axis_cross=None,
+        db_path=sql_write_path_hb['work'],
+        cal_path=sql_write_path_hb['daily'],
+        all_selected=True,
+        print_info=True
 ):
     if axis_cross:
         axis_cross = opts.TooltipOpts(trigger="axis", axis_pointer_type="cross")
@@ -191,60 +210,20 @@ def gen_grid(
 
 
 def index_fut_basis_wind(
-        index_code, start_date, end_date,
-        sql_path=sql_write_path_hb['daily'], table='futures_wind',
-        grid_width=1200, grid_height=400, zoom_left=0, zoom_right=100,
-        chart_pos_left=10, chart_pos_right=15,
+        index_code,
+        start_date,
+        end_date,
+        sql_path=sql_write_path_hb['daily'],
+        table='futures_wind',
+        grid_width=1200,
+        grid_height=400,
+        zoom_left=0,
+        zoom_right=100,
+        chart_pos_left=10,
+        chart_pos_right=15,
 ):
-    engine = create_engine(sql_path)
-
-    data_raw = pd.read_sql_query(
-        'select * from ' + table
-        + ' where `t_date`<=' + end_date.strftime('%Y%m%d')
-        + ' and `t_date`>=' + start_date.strftime('%Y%m%d')
-        + ' and `product`=\'' + index_code + '\' order by `t_date`',
-        engine
-    )
-
-    data_00 = data_raw[data_raw['symbol'] == index_code + '00.CFE'].reset_index(drop=True)
-    data_01 = data_raw[data_raw['symbol'] == index_code + '01.CFE'].reset_index(drop=True)
-    data_02 = data_raw[data_raw['symbol'] == index_code + '02.CFE'].reset_index(drop=True)
-    data_03 = data_raw[data_raw['symbol'] == index_code + '03.CFE'].reset_index(drop=True)
-
-    data_00['remain'] = (data_00['delist_date'] - data_00['t_date']).map(lambda x: x.days)
-    data_00['basis'] = round(-data_00['basis'] / data_00['underlying'] / data_00['remain'] * 365 * 100, 2)
-    data_00['basis_chg'] = round(
-        -(
-            data_00['close'] / data_00['close'].shift(1)
-            - data_00['underlying'] / data_00['underlying'].shift(1)
-        ) * 100, 2
-    )
-
-    data_01['remain'] = (data_01['delist_date'] - data_01['t_date']).map(lambda x: x.days)
-    data_01['basis'] = round(-data_01['basis'] / data_01['underlying'] / data_01['remain'] * 365 * 100, 2)
-    data_01['basis_chg'] = round(
-        (
-                data_01['close'] / data_01['close'].shift(1)
-                - data_01['underlying'] / data_01['underlying'].shift(1)
-        ) * 100, 2
-    )
-
-    data_02['remain'] = (data_02['delist_date'] - data_02['t_date']).map(lambda x: x.days)
-    data_02['basis'] = round(-data_02['basis'] / data_02['underlying'] / data_02['remain'] * 365 * 100, 2)
-    data_02['basis_chg'] = round(
-        (
-                data_02['close'] / data_02['close'].shift(1)
-                - data_02['underlying'] / data_02['underlying'].shift(1)
-        ) * 100, 2
-    )
-
-    data_03['remain'] = (data_03['delist_date'] - data_03['t_date']).map(lambda x: x.days)
-    data_03['basis'] = round(-data_03['basis'] / data_03['underlying'] / data_03['remain'] * 365 * 100, 2)
-    data_03['basis_chg'] = round(
-        (
-                data_03['close'] / data_03['close'].shift(1)
-                - data_03['underlying'] / data_03['underlying'].shift(1)
-        ) * 100, 2
+    data_00, data_01, data_02, data_03 = wind_stk_index_basis(
+        code=index_code, start_date=start_date, end_date=end_date, sql_path=sql_path, table=table
     )
 
     web = Line(
@@ -302,7 +281,7 @@ def index_fut_basis_wind(
                 )
     ).set_global_opts(
         title_opts=opts.TitleOpts(
-            title=data_raw['t_date'][len(data_raw) - 1]
+            title=data_00['t_date'][len(data_00) - 1]
         ),
         tooltip_opts=opts.TooltipOpts(trigger="axis", axis_pointer_type="cross"),
         # toolbox_opts=opts.ToolboxOpts(is_show=True),
@@ -415,10 +394,17 @@ def index_fut_basis_wind(
 
 
 def index_fut_basis_wind_detail(
-        index_code, start_date, end_date,
-        sql_path=sql_write_path_hb['daily'], table='futures_wind',
-        grid_width=1200, grid_height=400, zoom_left=0, zoom_right=100,
-        chart_pos_left=10, chart_pos_right=15,
+        index_code,
+        start_date,
+        end_date,
+        sql_path=sql_write_path_hb['daily'],
+        table='futures_wind',
+        grid_width=1200,
+        grid_height=400,
+        zoom_left=0,
+        zoom_right=100,
+        chart_pos_left=10,
+        chart_pos_right=15,
 ):
     engine = create_engine(sql_path)
 
@@ -572,9 +558,15 @@ def index_fut_basis_wind_detail(
 
 
 def index_fut_basis_hsjy(
-        index_code, start_date, end_date,
-        grid_width=1200, grid_height=400, zoom_left=0, zoom_right=100,
-        chart_pos_left=10, chart_pos_right=15,
+        index_code,
+        start_date,
+        end_date,
+        grid_width=1200,
+        grid_height=400,
+        zoom_left=0,
+        zoom_right=100,
+        chart_pos_left=10,
+        chart_pos_right=15,
 ):
     data = load_fut_fin(index_code=index_code, start_date=start_date, end_date=end_date)
     data_o = load_index(index_list=[underlying_code[index_code]], start_date=start_date, end_date=end_date)
@@ -722,9 +714,15 @@ def index_fut_basis_hsjy(
 
 
 def index_fut_basis_hsjy_detail(
-        index_code, start_date, end_date,
-        grid_width=1200, grid_height=400, zoom_left=0, zoom_right=100,
-        chart_pos_left=10, chart_pos_right=15,
+        index_code,
+        start_date,
+        end_date,
+        grid_width=1200,
+        grid_height=400,
+        zoom_left=0,
+        zoom_right=100,
+        chart_pos_left=10,
+        chart_pos_right=15,
 ):
 
     data = load_fut_fin(index_code=index_code, start_date=start_date, end_date=end_date)
