@@ -6,7 +6,7 @@ from hbshare.quant.Kevin.asset_allocation.macro_index.currency import Currency,
 from hbshare.quant.Kevin.asset_allocation.macro_index.credit import Credit
 from hbshare.quant.Kevin.asset_allocation.macro_index.inflation import Inflation
 from hbshare.quant.Kevin.asset_allocation.macro_index.eco_increase import EconomyIncrease
-from hbshare.quant.Kevin.asset_allocation.macro_index.rates_and_price import RatesAndPrice
+from hbshare.quant.Kevin.asset_allocation.macro_index.rates_and_price import RatesAndPrice, DRrates
 from hbshare.quant.Kevin.asset_allocation.macro_index.processed_market_index import MarketIndex
 from hbshare.quant.Kevin.asset_allocation.macro_index.stock_market import StockValuation, DividendRatio
 from hbshare.quant.Kevin.asset_allocation.macro_index.stock_cash_flow import StockCashFlow
@@ -94,9 +94,11 @@ def update_daily(start_date, end_date):
     OptionIV(start_date.replace('-', ''), end_date.replace('-', '')).get_construct_result()
     # 基差数据
     StockSharePriceIndex(start_date, end_date).get_construct_result()
+    # DR数据
+    DRrates(start_date, end_date).get_construct_result()
 
 
 if __name__ == '__main__':
-    update_daily(start_date='2022-07-25', end_date='2022-07-25')
-    # update_monthly('2022-06-10', '2022-06-30')
-    # update_weekly(start_date='2021-09-01', end_date='2022-06-30')
+    update_daily(start_date='2022-10-13', end_date='2022-10-13')
+    # update_monthly('2022-07-10', '2022-09-30')
+    # update_weekly(start_date='2021-09-01', end_date='2022-09-30')
