@@ -1,6 +1,7 @@
 """
 Alpha标的表现统计
 """
+import os
 import pandas as pd
 import hbshare as hbs
 import datetime
@@ -18,34 +19,45 @@ alpha_dict = {
         "星阔春山一号": "SQF231"
     },
     "zz500": {
-        "明汯价值成长1期3号": "SEE194",
-        "启林中证500指数增强8号": "SNL641",
-        "幻方量化500指数专享60号1期": "SNA691",
-        "天演启航量化500指增": "SQP881",
-        "诚奇睿盈500指数增强尊享1号": "SQK764",
-        "星阔广厦1号中证500指数增强": "SNU706",
-        "量锐62号": "SGR954",
-        "因诺聚配中证500指数增强": "SGX346",
-        "赫富500指数增强一号": "SEP463",
-        "量派500增强8号": "SNJ513",
-        "凡二英火5号": "SJM016",
-        "希格斯旅行者1号": "SJA569",
-        "伯兄建康": "SQT564",
-        "概率500指增1号": "SQT076"
-              },
+        "启林": "SGY379",
+        "诚奇": "SLS817",
+        "幻方": "SEC185",
+        "九坤": "ST9804",
+        "明汯": "SEE194",
+        "天演": "P20830",
+        "星阔": "SNU706",
+        "卓识": "SGA015",
+        "衍复": "SJH866",
+        "黑翼": "SEM323",
+        "世纪前沿": "SGP682",
+        "乾象": "P48470",
+        "宽德": "SJF555",
+        "因诺": "SGX346",
+        "伯兄": "SQT564",
+        "概率": "SQT076",
+        "赫富": "SEP463",
+        "量锐": "SGR954",
+        "量派": "SNJ513",
+        "茂源": "SJM016",
+        "希格斯": "SLE315",
+        "白鹭": "SQB109",
+        "朋锦仲阳": "SGN254",
+        "衍合": "SLG867",
+        "弈倍": "SY0096"},
     "zz1000": {
-        "启林广进中证1000指数增强1号": "SSU078",
-        "明汯量化中小盘增强1号": "SGG585",
-        # "量派中证1000增强12号": "SQJ816",
-        "凡二量化中证1000增强1号": "SSC067",
-        # "希格斯旅行者中证1000指数增强1号": "SSD078",
-        "概率1000指增1号": "SQQ803"},
+        "启林": "SSU078",
+        "明汯": "SGG585",
+        "凡二": "SSC067",
+        "衍复": "SJM688",
+        "概率": "SQQ803",
+        "星阔": "SQF225"
+    },
     "all_market": {
-        "明汯股票精选13号": "SSL078",
-        "天演赛能": "P22984",
-        "诚奇睿盈优选尊享1号": "SSU249",
-        "星阔山海6号股票优选": "SSE288"
-                   },
+        "明汯": "SSL078",
+        "天演": "P22984",
+        "诚奇": "SSU249",
+        "星阔": "SSE288"
+    },
     "market_neutral": {
         "明汯中性7号1期": "SEL756",
         "天演广全": "SLC213",
@@ -64,8 +76,9 @@ alpha_dict = {
 
 
 class AlphaPerformance:
-    def __init__(self, start_date, end_date, fund_info_dict):
+    def __init__(self, start_date, pre_date, end_date, fund_info_dict):
         self.start_date = start_date
+        self.pre_date = pre_date
         self.end_date = end_date
         self.fund_info_dict = fund_info_dict
         self._load_data()
@@ -149,6 +162,11 @@ class AlphaPerformance:
     def get_construct_result(self):
         trading_day_list = self._load_calendar()
 
+        nan_excel = pd.DataFrame()
+        file = os.path.join("D:\\量化产品跟踪\\代销及FOF标的", r"AlphaPerf_{}.xlsx".format(self.end_date))
+        nan_excel.to_excel(file)
+        writer = pd.ExcelWriter(file)
+
         # 300指增
         # nav_df = self.nav_series_dict['hs300'].reindex(trading_day_list).dropna(how='all')
         # return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
@@ -157,45 +175,69 @@ class AlphaPerformance:
         # return_df = return_df.sub(benchmark_series['benchmark'], axis=0)
         # 500指增
         nav_df = self.nav_series_dict['zz500'].reindex(trading_day_list).dropna(how='all')
+        # 月末日期
+        tmp = pd.DataFrame({"trade_date": nav_df.index})
+        tmp['month'] = tmp['trade_date'].apply(lambda x: datetime.datetime.strptime(x, '%Y%m%d').month)
+        tmp['next_month'] = tmp['month'].shift(-1).fillna(0.).astype(int)
+        tmp = tmp[tmp['month'] != tmp['next_month']]
+        month_end = tmp['trade_date'].tolist()
+
         benchmark_series = self._load_benchmark('000905', self.start_date, self.end_date).reindex(
             trading_day_list).pct_change().fillna(0.)
         return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
         return_df = return_df.sub(benchmark_series['benchmark'], axis=0)
-        # (1 + return_df).cumprod().loc[['20211231', '20220128', '20220225', '20220325'],:].pct_change().dropna().T.to_clipboard()
-        adj_nav_df = (1 + return_df).cumprod()
-        self.plotly_line(
-            adj_nav_df, "500指增产品走势图", "D:\\量化产品跟踪\\代销及FOF标的\\500指增走势.html", figsize=(1200, 600))
+        # 月度超额收益
+        month_excess = (1 + return_df).cumprod().reindex(month_end).pct_change().dropna().sort_index().T
+        month_excess.columns = [x[:6] for x in month_excess.columns]
+        month_excess.to_excel(writer, sheet_name="500指增月度超额")
+        # 当月超额
+        week_excess = return_df[return_df.index > self.pre_date].sort_index().T
+        week_excess.to_excel(writer, sheet_name="500指增当月周度超额")
+
         # 1000指增
         nav_df = self.nav_series_dict['zz1000'].reindex(trading_day_list).dropna(how='all')
         benchmark_series = self._load_benchmark('000852', self.start_date, self.end_date).reindex(
             trading_day_list).pct_change().fillna(0.)
         return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
         return_df = return_df.sub(benchmark_series['benchmark'], axis=0)
-        adj_nav_df = (1 + return_df).cumprod()
-        self.plotly_line(
-            adj_nav_df, "1000指增产品走势图", "D:\\量化产品跟踪\\代销及FOF标的\\1000指增走势.html", figsize=(1200, 600))
+        # 月度超额收益
+        month_excess = (1 + return_df).cumprod().reindex(month_end).pct_change().dropna().sort_index().T
+        month_excess.columns = [x[:6] for x in month_excess.columns]
+        month_excess.to_excel(writer, sheet_name="1000指增月度超额")
+        # 当月超额
+        week_excess = return_df[return_df.index > self.pre_date].sort_index().T
+        week_excess.to_excel(writer, sheet_name="1000指增当月周度超额")
+
         # 全市场选股
         nav_df = self.nav_series_dict['all_market'].reindex(trading_day_list).dropna(how='all')
         benchmark_series = self._load_benchmark('000985', self.start_date, self.end_date).reindex(
             trading_day_list).pct_change().fillna(0.)
         return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
         return_df = return_df.sub(benchmark_series['benchmark'], axis=0)
-        adj_nav_df = (1 + return_df).cumprod()
-        self.plotly_line(
-            adj_nav_df, "量化多头产品走势图", "D:\\量化产品跟踪\\代销及FOF标的\\全市场选股走势.html", figsize=(1200, 600))
+        return_df = return_df[return_df.index >= '20211231']  # 全市场从22年开始看
+        # 月度超额收益
+        month_excess = (1 + return_df).cumprod().reindex(month_end).pct_change().dropna().sort_index().T
+        month_excess.columns = [x[:6] for x in month_excess.columns]
+        month_excess.to_excel(writer, sheet_name="全市场选股月度超额")
+        # 当月超额
+        week_excess = return_df[return_df.index > self.pre_date].sort_index().T
+        week_excess.to_excel(writer, sheet_name="全市场选股当月周度超额")
+
         # 市场中性
-        nav_df = self.nav_series_dict['market_neutral'].reindex(trading_day_list).dropna(how='all')
-        return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
-        adj_nav_df = (1 + return_df).cumprod()
-        self.plotly_line(
-            adj_nav_df, "市场中性产品走势图", "D:\\量化产品跟踪\\代销及FOF标的\\市场中性走势.html", figsize=(1200, 600))
+        # nav_df = self.nav_series_dict['market_neutral'].reindex(trading_day_list).dropna(how='all')
+        # return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
+        # adj_nav_df = (1 + return_df).cumprod()
+        # self.plotly_line(
+        #     adj_nav_df, "市场中性产品走势图", "D:\\量化产品跟踪\\代销及FOF标的\\市场中性走势.html", figsize=(1200, 600))
         # 可转债
-        nav_df = self.nav_series_dict['cb'].reindex(trading_day_list).dropna(how='all')
-        return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
-        adj_nav_df = (1 + return_df).cumprod()
-        self.plotly_line(adj_nav_df, "可转债套利产品走势图", "D:\\量化产品跟踪\\代销及FOF标的\\可转债走势.html",
-                         figsize=(1200, 600))
+        # nav_df = self.nav_series_dict['cb'].reindex(trading_day_list).dropna(how='all')
+        # return_df = nav_df.fillna(method='ffill').pct_change().fillna(0.)
+        # adj_nav_df = (1 + return_df).cumprod()
+        # self.plotly_line(adj_nav_df, "可转债套利产品走势图", "D:\\量化产品跟踪\\代销及FOF标的\\可转债走势.html",
+        #                  figsize=(1200, 600))
+
+        writer.save()
 
 
 if __name__ == '__main__':
-    AlphaPerformance('20211231', '20220401', alpha_dict).get_construct_result()
\ No newline at end of file
+    AlphaPerformance('20210520', '20220429', '20220527', alpha_dict).get_construct_result()
\ No newline at end of file
