@@ -24,7 +24,7 @@ class HoldingExtractor:
             if self.fund_name in ['因诺聚配中证500指数增强', '凡二中证500增强9号1期', '赫富500指数增强一号', '赫富1000指数增强一号',
                                   '宽德金选中证500指数增强6号', 'TEST', '量锐62号', '启林广进中证1000指数增强',
                                   '白鹭精选量化鲲鹏十号', '伯兄建康', '伯兄熙宁', '世纪前沿指数增强2号',
-                                  '云起量化指数增强1号', '罗维盈安凌云增强2号']:
+                                  '云起量化指数增强1号', '罗维盈安凌云增强2号', '朋锦永宁', '宽德中证1000指数增强8号']:
                 context = "市值占净值%"
                 if self.fund_name in ['伯兄建康', '伯兄熙宁']:
                     hd = 2
@@ -49,7 +49,10 @@ class HoldingExtractor:
             # 招商
             elif self.fund_name in ['星阔广厦1号中证500指数增强', '星阔上林1号', '星阔山海6号',
                                     '量客卓宇六号', '乾象中证500指数增强1号', '水木博雅500指增',
-                                    '概率1000指增1号', '概率500指增2号', '稳博中性稳稳系列1号', '稳博中性稳稳系列2号']:
+                                    '概率1000指增1号', '概率500指增2号', '稳博中性稳稳系列1号', '稳博中性稳稳系列2号',
+                                    '稳博1000指数增强1号', '蒙玺量化对冲钧衡3号', '天戈500指增', '宽德九臻',
+                                    '顽岩中证500指数增强1号', '托特中证500指数增强2号', '卓识500指数增强一号', '卓识辰熙',
+                                    '世纪前沿指数增强24号', '世纪前沿量化优选一号']:
                 header = 6 if self.fund_name in ['星阔上林1号', '水木博雅500指增', '乾象中证500指数增强1号',
                                                  '稳博中性稳稳系列1号', '稳博中性稳稳系列2号'] else 7
                 data = pd.read_excel(
@@ -59,11 +62,13 @@ class HoldingExtractor:
                 df = pd.concat([sh, sz], axis=0)
                 df['ticker'] = df['科目代码'].apply(lambda x: x.split(' ')[0][-6:])
                 df.rename(columns={"科目名称": "sec_name", "市值占比": "weight"}, inplace=True)
-                if self.fund_name == "乾象中证500指数增强1号":
+                if self.fund_name in ["乾象中证500指数增强1号", "天戈500指增"]:
                     # 处理一下分红
                     ratio = data[data['科目代码'] == '资产净值']['市值占比'].values[0] / \
                             data[data['科目代码'] == '资产合计']['市值占比'].values[0]
                     df['weight'] *= ratio
+                if self.fund_name == '蒙玺量化对冲钧衡3号':
+                    df['weight'] = df['weight'] / df['weight'].sum()
                 df['weight'] *= 100.
             # 海通但有信用账户
             elif self.fund_name in ['朋锦金石炽阳']:
@@ -93,7 +98,7 @@ class HoldingExtractor:
             ['trade_date', 'ticker', 'sec_name'])['weight'].sum().reset_index()
         portfolio_weight_df['fund_name'] = self.fund_name
 
-        # print(portfolio_weight_df.groupby('trade_date')['weight'].sum().sort_index())
+        print(portfolio_weight_df.groupby('trade_date')['weight'].sum().sort_index())
 
         return portfolio_weight_df
 
@@ -123,5 +128,5 @@ class HoldingExtractor:
 
 
 if __name__ == '__main__':
-    HoldingExtractor(data_path='D:\\估值表基地\\稳博中性稳稳系列2号', table_name="private_fund_holding",
-                     fund_name="稳博中性稳稳系列2号").writeToDB()
+    HoldingExtractor(data_path='D:\\估值表基地\\白鹭精选量化鲲鹏十号', table_name="private_fund_holding",
+                     fund_name="白鹭精选量化鲲鹏十号").writeToDB()
