@@ -1231,8 +1231,8 @@ class AlphaEnvPlot:
 
 if __name__ == '__main__':
     # 超额收益Y
-    fund_data = pd.read_excel('D:\\研究基地\\G-专题报告\\量化超额市场微观环境分析\\数据相关.xlsx', sheet_name=0)
-    alpha_series = AlphaSeries('20181228', '20220422', fund_data).calculate()
+    # fund_data = pd.read_excel('D:\\研究基地\\G-专题报告\\量化超额市场微观环境分析\\数据相关.xlsx', sheet_name=0)
+    # alpha_series = AlphaSeries('20181228', '20220422', fund_data).calculate()
 
     # 流动性因子
     # start_date = '20190101'
@@ -1254,6 +1254,13 @@ if __name__ == '__main__':
     # summary_analysis(alpha_series)
 
     # main class
-    AlphaMonitorWeekly('20220722', is_increment=1).get_construct_result()
+    AlphaMonitorWeekly('20220930', is_increment=1).get_construct_result()
 
-    # AlphaEnvPlot('20220722').quantile_plot()
\ No newline at end of file
+    # AlphaEnvPlot('20220930').quantile_plot()
+
+    # start_date = '20210101'
+    # end_date = '20220422'
+    # trading_day_list = get_trading_day_list(start_date, end_date)
+    # from tqdm import tqdm
+    # for trading_day in tqdm(trading_day_list):
+    #     AlphaMonitorWeekly(trading_day, is_increment=1).calculate_liq_factor()
\ No newline at end of file
