@@ -50,9 +50,20 @@ class HoldingAnalysor:
         engine = create_engine(engine_params)
         holding_df = pd.read_sql(sql_script, engine)
         holding_df['trade_date'] = holding_df['trade_date'].apply(lambda x: datetime.datetime.strftime(x, '%Y%m%d'))
-        # holding_df['weight'] /= holding_df['weight'].sum()
+
+        # summary
+        # sql_script = "SELECT * FROM private_fund_holding where trade_date = {}".format(self.trade_date)
+        # engine = create_engine(engine_params)
+        # holding_df = pd.read_sql(sql_script, engine)
+        # holding_df['trade_date'] = holding_df['trade_date'].apply(lambda x: datetime.datetime.strftime(x, '%Y%m%d'))
+        # holding_df = holding_df[holding_df['fund_name'].str.contains('500')]
+        # holding_df['total_weight'] = holding_df.groupby('fund_name')['weight'].transform('sum')
+        # holding_df['weight'] = 100 * holding_df['weight'] / holding_df['total_weight']
+        # num = len(holding_df['fund_name'].unique())
+        # print(num)
 
         return holding_df.set_index('ticker')['weight'] / 100.
+        # return holding_df.groupby('ticker')['weight'].sum() / 100. / num
 
     def _load_benchmark_weight_series(self, date):
         sql_script = "SELECT * FROM hsjy_gg.SecuMain where SecuCategory = 4 and SecuCode = '{}'".format(
@@ -426,9 +437,9 @@ if __name__ == '__main__':
     # d_list = ['20201231', '20210131', '20210228']
     # tmp = HoldingAnalysor("星阔广厦1号中证500指数增强", "20220128", "000905").get_construct_result(isPlot=False)
 
-    hd_analysor = HoldingAnalysor("量锐62号", "20220531", "000905")
+    # hd_analysor = HoldingAnalysor("量锐62号", "20220731", "000905")
 
-    tmp = HoldingAnalysor("量锐62号", "20220531", "000905").get_construct_result(isPlot=False)
+    tmp = HoldingAnalysor("稳博1000指数增强1号", "20220831", "000852").get_construct_result(isPlot=False)
     print(tmp['style_df'])
     # dis_df = HoldingDistribution('20210310', '20220602', '因诺聚配中证500指数增强').get_construct_result()
     # print(dis_df)
\ No newline at end of file
