@@ -1,6 +1,7 @@
 """
 季度资产报告辅助程序
 """
+import numpy as np
 import pandas as pd
 from datetime import datetime
 import os
@@ -33,8 +34,8 @@ class QuarterAssetAllocationReport:
         df = df[(df['month'] != df['next_month']) & (df['t_date'] >= self.start_date)]
         trading_day_list = sorted(df['t_date'].tolist())
 
-        from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_trading_day_list
-        trading_day_list = get_trading_day_list(self.start_date, self.end_date, frequency="week")
+        # from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_trading_day_list
+        # trading_day_list = get_trading_day_list(self.start_date, self.end_date, frequency="week")
 
         # type
         data_param = dict()
@@ -83,6 +84,8 @@ class QuarterAssetAllocationReport:
         return_300['average'] = return_300[return_300.columns[:-1]].mean(axis=1)
         return_300['ave_excess'] = return_300['average'] - return_300['benchmark']
 
+        # 微调
+        data_1000.loc[:"20220211", "珠海宽德九睦"] = np.NaN
         return_1000 = data_1000.pct_change(limit=1).dropna(axis=0, how='all')
         return_1000['average'] = return_1000[return_1000.columns[:-1]].mean(axis=1)
         return_1000['ave_excess'] = return_1000['average'] - return_1000['benchmark']
@@ -186,8 +189,8 @@ def plotly_line(df, day_list, title_text, save_path):
 
 if __name__ == '__main__':
     allo_rep = QuarterAssetAllocationReport(
-        start_date='20191228', end_date='20220715',
-        data_path='D:\\量化产品跟踪\\指数增强', file_name='指增-20220715.xlsx')
+        start_date='20210930', end_date='20220930',
+        data_path='D:\\量化产品跟踪\\指数增强', file_name='指增-20220930.xlsx')
     # allo_rep = QuarterAssetAllocationReport(
     #     start_date='20161230', end_date='20220527',
     #     data_path='D:\\量化产品跟踪\\指数增强', file_name='指增-20220527.xlsx')
