@@ -2,6 +2,8 @@
 Kevin的标的池跟踪模块：tracker
 """
 import os
+
+import numpy as np
 import pandas as pd
 import hbshare as hbs
 import datetime
@@ -88,8 +90,8 @@ class FundTracker:
         # pre_date = (end_dt - datetime.timedelta(days=180)).strftime('%Y%m%d')
         # trading_day_list = get_trading_day_list(pre_date, self.end_date, frequency="week")[-9:]
         # 22年以来
-        # pre_date = '20211231'
-        pre_date = '20200706'
+        pre_date = '20211224'
+        # pre_date = '20210521'
         trading_day_list = get_trading_day_list(pre_date, self.end_date, frequency="week")
 
         return_dict = {}
@@ -97,10 +99,14 @@ class FundTracker:
         # 500指增
         fund_dict = config_df[config_df['level2type'] == "500指增"].set_index('fund_name')['fund_id'].to_dict()
         fund_nav = get_fund_nav_from_sql(pre_date, self.end_date, fund_dict).reindex(
-            trading_day_list).dropna(axis=1)
+            trading_day_list)
+        fund_nav.loc["20220923", "卓识伟业"] = 2.0746
+        fund_nav.loc["20220930", "卓识伟业"] = 2.0022
+        fund_nav = fund_nav.dropna(axis=1)
         benchmark_series = self._load_benchmark(pre_date, self.end_date, '000905').reindex(
             trading_day_list).pct_change().dropna()
         return_df = fund_nav.pct_change().dropna().sub(benchmark_series, axis=0).sort_index()
+        return_df.loc[:"20211231", "白鹭精选量化鲲鹏十号"] = np.NaN
         return_dict['500_alpha'] = return_df
         # 1000指增
         fund_dict = config_df[config_df['level2type'] == "1000指增"].set_index('fund_name')['fund_id'].to_dict()
@@ -283,4 +289,4 @@ class FundTracker:
 
 if __name__ == '__main__':
     # write_config_to_DB("tracker", is_increment=1)
-    FundTracker('20220624').run()
\ No newline at end of file
+    FundTracker('20220930').run()
\ No newline at end of file
